@@ -72,6 +72,8 @@ Req-started-unread-response    _CS_REQ_STARTED    <response_class>
 Req-sent-unread-response       _CS_REQ_SENT       <response_class>
 """
 
+from __future__ import print_function
+
 import collections
 from array import array
 import os
@@ -373,7 +375,7 @@ class HTTPResponse(object):
         if len(line) > _MAXLINE:
             raise LineTooLong("header line")
         if self.debuglevel > 0:
-            print "reply:", repr(line)
+            print("reply:", repr(line))
         if not line:
             # Presumably, the server closed the connection before
             # sending a valid response.
@@ -425,7 +427,7 @@ class HTTPResponse(object):
                 if not skip:
                     break
                 if self.debuglevel > 0:
-                    print "header:", skip
+                    print("header:", skip)
 
         self.status = status
         self.reason = reason.strip()
@@ -448,7 +450,7 @@ class HTTPResponse(object):
         self.msg = HTTPMessage(self.fp, 0)
         if self.debuglevel > 0:
             for hdr in self.msg.headers:
-                print "header:", hdr,
+                print("header:", hdr, end=' ')
 
         # don't let the msg keep an fp
         self.msg.fp = None
@@ -806,14 +808,14 @@ class HTTPConnection(object):
                 raise NotConnected()
 
         if self.debuglevel > 0:
-            print "send:", repr(data)
+            print("send:", repr(data))
         blocksize = 8192
         # The read() method of array.array in Py2 is a red herring;
         # it is a deprecated redirector to array.fromfile that takes two args,
         # not one. So we can't use it.
         if hasattr(data, "read") and not isinstance(data, array):
             if self.debuglevel > 0:
-                print "sendIng a read()able"
+                print("sendIng a read()able")
             encode = False
             try:
                 mode = data.mode
@@ -825,7 +827,7 @@ class HTTPConnection(object):
                 if "b" not in mode:
                     encode = True
                     if self.debuglevel > 0:
-                        print "encoding file using iso-8859-1"
+                        print("encoding file using iso-8859-1")
             while 1:
                 datablock = data.read(blocksize)
                 if not datablock:
@@ -1038,14 +1040,14 @@ class HTTPConnection(object):
         thelen = None
         try:
             thelen = str(len(body))
-        except TypeError, te:
+        except TypeError as te:
             # If this is a file-like object, try to
             # fstat its file descriptor
             try:
                 thelen = str(os.fstat(body.fileno()).st_size)
             except (AttributeError, OSError):
                 # Don't send a length if this failed
-                if self.debuglevel > 0: print "Cannot stat!!"
+                if self.debuglevel > 0: print("Cannot stat!!")
 
         if thelen is not None:
             self.putheader('Content-Length', thelen)
